""" openconfig_telemetry 

Data model which creates the configuration for the telemetry
systems and functions on the device.

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class TelemetryStreamProtocol(Enum):
    """
    TelemetryStreamProtocol (Enum Class)

    Selectable protocols for transport

    of the telemetry stream

    .. data:: TCP = 0

        TCP protocol transport for the stream

    .. data:: UDP = 1

        UDP protocol transport for the stream

    """

    TCP = Enum.YLeaf(0, "TCP")

    UDP = Enum.YLeaf(1, "UDP")


class TelemetrySystem(_Entity_):
    """
    Top level configuration and state for the
    device's telemetry system.
    
    .. attribute:: sensor_groups
    
        Top level container for sensor\-groups
    
        **type**:  :py:class:`SensorGroups<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.SensorGroups>`
    
    .. attribute:: destination_groups
    
        Top level container for destination group configuration and state
    
        **type**:  :py:class:`DestinationGroups<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.DestinationGroups>`
    
    .. attribute:: subscriptions
    
        This container holds information for both persistent and dynamic telemetry subscriptions
    
        **type**:  :py:class:`Subscriptions<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions>`
    
    """
    _prefix = 'oc-telemetry'
    _revision = '2016-02-04'

    def __init__(self):
        super().__init__()
        self._top_entity = None

        self.yang_name = "telemetry-system"
        self.yang_parent_name = "openconfig-telemetry"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("sensor-groups", ("sensor_groups", TelemetrySystem.SensorGroups)), ("destination-groups", ("destination_groups", TelemetrySystem.DestinationGroups)), ("subscriptions", ("subscriptions", TelemetrySystem.Subscriptions))])
        self._leafs = OrderedDict()

        self.sensor_groups = TelemetrySystem.SensorGroups()
        self.sensor_groups.parent = self
        self._children_name_map["sensor_groups"] = "sensor-groups"

        self.destination_groups = TelemetrySystem.DestinationGroups()
        self.destination_groups.parent = self
        self._children_name_map["destination_groups"] = "destination-groups"

        self.subscriptions = TelemetrySystem.Subscriptions()
        self.subscriptions.parent = self
        self._children_name_map["subscriptions"] = "subscriptions"
        self._segment_path = lambda: "openconfig-telemetry:telemetry-system"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(TelemetrySystem, [], name, value)

    class SensorGroups(_Entity_):
        """
        Top level container for sensor\-groups.
        
        .. attribute:: sensor_group
        
            List of telemetry sensory groups on the local system, where a sensor grouping represents a resuable grouping of multiple paths and exclude filters
        
            **type**: list of    :py:class:`SensorGroup<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.SensorGroups.SensorGroup>`
        
        """
        _prefix = 'oc-telemetry'
        _revision = '2016-02-04'

        def __init__(self):
            super().__init__()

            self.yang_name = "sensor-groups"
            self.yang_parent_name = "telemetry-system"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("sensor-group", ("sensor_group", TelemetrySystem.SensorGroups.SensorGroup))])
            self._leafs = OrderedDict()

            self.sensor_group = YList(self)
            self._segment_path = lambda: "sensor-groups"
            self._absolute_path = lambda: "openconfig-telemetry:telemetry-system/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(TelemetrySystem.SensorGroups, [], name, value)

        class SensorGroup(_Entity_):
            """
            List of telemetry sensory groups on the local
            system, where a sensor grouping represents a resuable
            grouping of multiple paths and exclude filters.
            
            .. attribute:: sensor_group_id  (key)
            
                Reference to the name or identifier of the sensor grouping
            
                **type**: str
            
                **refers to**:  :py:class:`sensor_group_id<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.SensorGroups.SensorGroup.Config>`
            
            .. attribute:: config
            
                Configuration parameters relating to the telemetry sensor grouping
            
                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.SensorGroups.SensorGroup.Config>`
            
            .. attribute:: state
            
                State information relating to the telemetry sensor group
            
                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.SensorGroups.SensorGroup.State>`
            
                **config**: False
            
            .. attribute:: sensor_paths
            
                Top level container to hold a set of sensor paths grouped together
            
                **type**:  :py:class:`SensorPaths<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.SensorGroups.SensorGroup.SensorPaths>`
            
            """
            _prefix = 'oc-telemetry'
            _revision = '2016-02-04'

            def __init__(self):
                super().__init__()

                self.yang_name = "sensor-group"
                self.yang_parent_name = "sensor-groups"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['sensor_group_id']
                self._child_classes = OrderedDict([("config", ("config", TelemetrySystem.SensorGroups.SensorGroup.Config)), ("state", ("state", TelemetrySystem.SensorGroups.SensorGroup.State)), ("sensor-paths", ("sensor_paths", TelemetrySystem.SensorGroups.SensorGroup.SensorPaths))])
                self._leafs = OrderedDict([
                    ('sensor_group_id', (YLeaf(YType.str, 'sensor-group-id'), ['str'])),
                ])
                self.sensor_group_id = None

                self.config = TelemetrySystem.SensorGroups.SensorGroup.Config()
                self.config.parent = self
                self._children_name_map["config"] = "config"

                self.state = TelemetrySystem.SensorGroups.SensorGroup.State()
                self.state.parent = self
                self._children_name_map["state"] = "state"

                self.sensor_paths = TelemetrySystem.SensorGroups.SensorGroup.SensorPaths()
                self.sensor_paths.parent = self
                self._children_name_map["sensor_paths"] = "sensor-paths"
                self._segment_path = lambda: "sensor-group" + "[sensor-group-id='" + str(self.sensor_group_id) + "']"
                self._absolute_path = lambda: "openconfig-telemetry:telemetry-system/sensor-groups/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(TelemetrySystem.SensorGroups.SensorGroup, ['sensor_group_id'], name, value)

            class Config(_Entity_):
                """
                Configuration parameters relating to the
                telemetry sensor grouping
                
                .. attribute:: sensor_group_id
                
                    Name or identifier for the sensor group itself. Will be referenced by other configuration specifying a sensor group
                
                    **type**: str
                
                """
                _prefix = 'oc-telemetry'
                _revision = '2016-02-04'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "config"
                    self.yang_parent_name = "sensor-group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('sensor_group_id', (YLeaf(YType.str, 'sensor-group-id'), ['str'])),
                    ])
                    self.sensor_group_id = None
                    self._segment_path = lambda: "config"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(TelemetrySystem.SensorGroups.SensorGroup.Config, ['sensor_group_id'], name, value)


            class State(_Entity_):
                """
                State information relating to the telemetry
                sensor group
                
                .. attribute:: sensor_group_id
                
                    Name or identifier for the sensor group itself. Will be referenced by other configuration specifying a sensor group
                
                    **type**: str
                
                    **config**: False
                
                """
                _prefix = 'oc-telemetry'
                _revision = '2016-02-04'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "state"
                    self.yang_parent_name = "sensor-group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('sensor_group_id', (YLeaf(YType.str, 'sensor-group-id'), ['str'])),
                    ])
                    self.sensor_group_id = None
                    self._segment_path = lambda: "state"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(TelemetrySystem.SensorGroups.SensorGroup.State, ['sensor_group_id'], name, value)


            class SensorPaths(_Entity_):
                """
                Top level container to hold a set of sensor
                paths grouped together
                
                .. attribute:: sensor_path
                
                    List of paths in the model which together comprise a sensor grouping. Filters for each path to exclude items are also provided
                
                    **type**: list of    :py:class:`SensorPath<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.SensorGroups.SensorGroup.SensorPaths.SensorPath>`
                
                """
                _prefix = 'oc-telemetry'
                _revision = '2016-02-04'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "sensor-paths"
                    self.yang_parent_name = "sensor-group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("sensor-path", ("sensor_path", TelemetrySystem.SensorGroups.SensorGroup.SensorPaths.SensorPath))])
                    self._leafs = OrderedDict()

                    self.sensor_path = YList(self)
                    self._segment_path = lambda: "sensor-paths"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(TelemetrySystem.SensorGroups.SensorGroup.SensorPaths, [], name, value)

                class SensorPath(_Entity_):
                    """
                    List of paths in the model which together
                    comprise a sensor grouping. Filters for each path
                    to exclude items are also provided.
                    
                    .. attribute:: path  (key)
                    
                        Reference to the path of interest
                    
                        **type**: str
                    
                        **refers to**:  :py:class:`path<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.SensorGroups.SensorGroup.SensorPaths.SensorPath.Config>`
                    
                    .. attribute:: config
                    
                        Configuration parameters to configure a set of data model paths as a sensor grouping
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.SensorGroups.SensorGroup.SensorPaths.SensorPath.Config>`
                    
                    .. attribute:: state
                    
                        Configuration parameters to configure a set of data model paths as a sensor grouping
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.SensorGroups.SensorGroup.SensorPaths.SensorPath.State>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-telemetry'
                    _revision = '2016-02-04'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "sensor-path"
                        self.yang_parent_name = "sensor-paths"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['path']
                        self._child_classes = OrderedDict([("config", ("config", TelemetrySystem.SensorGroups.SensorGroup.SensorPaths.SensorPath.Config)), ("state", ("state", TelemetrySystem.SensorGroups.SensorGroup.SensorPaths.SensorPath.State))])
                        self._leafs = OrderedDict([
                            ('path', (YLeaf(YType.str, 'path'), ['str'])),
                        ])
                        self.path = None

                        self.config = TelemetrySystem.SensorGroups.SensorGroup.SensorPaths.SensorPath.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = TelemetrySystem.SensorGroups.SensorGroup.SensorPaths.SensorPath.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._segment_path = lambda: "sensor-path" + "[path='" + str(self.path) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(TelemetrySystem.SensorGroups.SensorGroup.SensorPaths.SensorPath, ['path'], name, value)

                    class Config(_Entity_):
                        """
                        Configuration parameters to configure a set
                        of data model paths as a sensor grouping
                        
                        .. attribute:: path
                        
                            Path to a section of operational state of interest (the sensor)
                        
                            **type**: str
                        
                        .. attribute:: exclude_filter
                        
                            Filter to exclude certain values out of the state values
                        
                            **type**: str
                        
                        """
                        _prefix = 'oc-telemetry'
                        _revision = '2016-02-04'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "sensor-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('path', (YLeaf(YType.str, 'path'), ['str'])),
                                ('exclude_filter', (YLeaf(YType.str, 'exclude-filter'), ['str'])),
                            ])
                            self.path = None
                            self.exclude_filter = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(TelemetrySystem.SensorGroups.SensorGroup.SensorPaths.SensorPath.Config, ['path', 'exclude_filter'], name, value)


                    class State(_Entity_):
                        """
                        Configuration parameters to configure a set
                        of data model paths as a sensor grouping
                        
                        .. attribute:: path
                        
                            Path to a section of operational state of interest (the sensor)
                        
                            **type**: str
                        
                            **config**: False
                        
                        .. attribute:: exclude_filter
                        
                            Filter to exclude certain values out of the state values
                        
                            **type**: str
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-telemetry'
                        _revision = '2016-02-04'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "sensor-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('path', (YLeaf(YType.str, 'path'), ['str'])),
                                ('exclude_filter', (YLeaf(YType.str, 'exclude-filter'), ['str'])),
                            ])
                            self.path = None
                            self.exclude_filter = None
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(TelemetrySystem.SensorGroups.SensorGroup.SensorPaths.SensorPath.State, ['path', 'exclude_filter'], name, value)






    class DestinationGroups(_Entity_):
        """
        Top level container for destination group configuration
        and state.
        
        .. attribute:: destination_group
        
            List of destination\-groups. Destination groups allow the reuse of common telemetry destinations across the telemetry configuration. An operator references a set of destinations via the configurable destination\-group\-identifier.  A destination group may contain one or more telemetry destinations
        
            **type**: list of    :py:class:`DestinationGroup<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.DestinationGroups.DestinationGroup>`
        
        """
        _prefix = 'oc-telemetry'
        _revision = '2016-02-04'

        def __init__(self):
            super().__init__()

            self.yang_name = "destination-groups"
            self.yang_parent_name = "telemetry-system"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("destination-group", ("destination_group", TelemetrySystem.DestinationGroups.DestinationGroup))])
            self._leafs = OrderedDict()

            self.destination_group = YList(self)
            self._segment_path = lambda: "destination-groups"
            self._absolute_path = lambda: "openconfig-telemetry:telemetry-system/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(TelemetrySystem.DestinationGroups, [], name, value)

        class DestinationGroup(_Entity_):
            """
            List of destination\-groups. Destination groups allow the
            reuse of common telemetry destinations across the
            telemetry configuration. An operator references a
            set of destinations via the configurable
            destination\-group\-identifier.
            
            A destination group may contain one or more telemetry
            destinations
            
            .. attribute:: group_id  (key)
            
                Unique identifier for the destination group
            
                **type**: str
            
                **refers to**:  :py:class:`group_id<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.DestinationGroups.DestinationGroup.Config>`
            
            .. attribute:: config
            
                Top level config container for destination groups
            
                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.DestinationGroups.DestinationGroup.Config>`
            
            .. attribute:: state
            
                Top level state container for destination groups
            
                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.DestinationGroups.DestinationGroup.State>`
            
                **config**: False
            
            .. attribute:: destinations
            
                The destination container lists the destination information such as IP address and port of the telemetry messages from the network element
            
                **type**:  :py:class:`Destinations<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.DestinationGroups.DestinationGroup.Destinations>`
            
            """
            _prefix = 'oc-telemetry'
            _revision = '2016-02-04'

            def __init__(self):
                super().__init__()

                self.yang_name = "destination-group"
                self.yang_parent_name = "destination-groups"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['group_id']
                self._child_classes = OrderedDict([("config", ("config", TelemetrySystem.DestinationGroups.DestinationGroup.Config)), ("state", ("state", TelemetrySystem.DestinationGroups.DestinationGroup.State)), ("destinations", ("destinations", TelemetrySystem.DestinationGroups.DestinationGroup.Destinations))])
                self._leafs = OrderedDict([
                    ('group_id', (YLeaf(YType.str, 'group-id'), ['str'])),
                ])
                self.group_id = None

                self.config = TelemetrySystem.DestinationGroups.DestinationGroup.Config()
                self.config.parent = self
                self._children_name_map["config"] = "config"

                self.state = TelemetrySystem.DestinationGroups.DestinationGroup.State()
                self.state.parent = self
                self._children_name_map["state"] = "state"

                self.destinations = TelemetrySystem.DestinationGroups.DestinationGroup.Destinations()
                self.destinations.parent = self
                self._children_name_map["destinations"] = "destinations"
                self._segment_path = lambda: "destination-group" + "[group-id='" + str(self.group_id) + "']"
                self._absolute_path = lambda: "openconfig-telemetry:telemetry-system/destination-groups/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(TelemetrySystem.DestinationGroups.DestinationGroup, ['group_id'], name, value)

            class Config(_Entity_):
                """
                Top level config container for destination groups
                
                .. attribute:: group_id
                
                    Unique identifier for the destination group
                
                    **type**: str
                
                """
                _prefix = 'oc-telemetry'
                _revision = '2016-02-04'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "config"
                    self.yang_parent_name = "destination-group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('group_id', (YLeaf(YType.str, 'group-id'), ['str'])),
                    ])
                    self.group_id = None
                    self._segment_path = lambda: "config"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(TelemetrySystem.DestinationGroups.DestinationGroup.Config, ['group_id'], name, value)


            class State(_Entity_):
                """
                Top level state container for destination groups
                
                .. attribute:: group_id
                
                    Unique identifier for destination group
                
                    **type**: str
                
                    **config**: False
                
                """
                _prefix = 'oc-telemetry'
                _revision = '2016-02-04'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "state"
                    self.yang_parent_name = "destination-group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('group_id', (YLeaf(YType.str, 'group-id'), ['str'])),
                    ])
                    self.group_id = None
                    self._segment_path = lambda: "state"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(TelemetrySystem.DestinationGroups.DestinationGroup.State, ['group_id'], name, value)


            class Destinations(_Entity_):
                """
                The destination container lists the destination
                information such as IP address and port of the
                telemetry messages from the network element.
                
                .. attribute:: destination
                
                    List of telemetry stream destinations
                
                    **type**: list of    :py:class:`Destination<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.DestinationGroups.DestinationGroup.Destinations.Destination>`
                
                """
                _prefix = 'oc-telemetry'
                _revision = '2016-02-04'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "destinations"
                    self.yang_parent_name = "destination-group"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination", ("destination", TelemetrySystem.DestinationGroups.DestinationGroup.Destinations.Destination))])
                    self._leafs = OrderedDict()

                    self.destination = YList(self)
                    self._segment_path = lambda: "destinations"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(TelemetrySystem.DestinationGroups.DestinationGroup.Destinations, [], name, value)

                class Destination(_Entity_):
                    """
                    List of telemetry stream destinations
                    
                    .. attribute:: destination_address  (key)
                    
                        Reference to the destination address of the telemetry stream
                    
                        **type**: union of the below types:
                    
                            **type**: str
                    
                                **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                            **type**: str
                    
                                **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                        **refers to**:  :py:class:`destination_address<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.DestinationGroups.DestinationGroup.Destinations.Destination.Config>`
                    
                    .. attribute:: destination_port  (key)
                    
                        Reference to the port number of the stream destination
                    
                        **type**: int
                    
                            **range:** 0..65535
                    
                        **refers to**:  :py:class:`destination_port<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.DestinationGroups.DestinationGroup.Destinations.Destination.Config>`
                    
                    .. attribute:: config
                    
                        Configuration parameters relating to telemetry destinations
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.DestinationGroups.DestinationGroup.Destinations.Destination.Config>`
                    
                    .. attribute:: state
                    
                        State information associated with telemetry destinations
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.DestinationGroups.DestinationGroup.Destinations.Destination.State>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-telemetry'
                    _revision = '2016-02-04'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "destination"
                        self.yang_parent_name = "destinations"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['destination_address','destination_port']
                        self._child_classes = OrderedDict([("config", ("config", TelemetrySystem.DestinationGroups.DestinationGroup.Destinations.Destination.Config)), ("state", ("state", TelemetrySystem.DestinationGroups.DestinationGroup.Destinations.Destination.State))])
                        self._leafs = OrderedDict([
                            ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str'])),
                            ('destination_port', (YLeaf(YType.str, 'destination-port'), ['int'])),
                        ])
                        self.destination_address = None
                        self.destination_port = None

                        self.config = TelemetrySystem.DestinationGroups.DestinationGroup.Destinations.Destination.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = TelemetrySystem.DestinationGroups.DestinationGroup.Destinations.Destination.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._segment_path = lambda: "destination" + "[destination-address='" + str(self.destination_address) + "']" + "[destination-port='" + str(self.destination_port) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(TelemetrySystem.DestinationGroups.DestinationGroup.Destinations.Destination, ['destination_address', 'destination_port'], name, value)

                    class Config(_Entity_):
                        """
                        Configuration parameters relating to
                        telemetry destinations
                        
                        .. attribute:: destination_address
                        
                            IP address of the telemetry stream destination
                        
                            **type**: union of the below types:
                        
                                **type**: str
                        
                                    **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                                **type**: str
                        
                                    **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                            Protocol (udp or tcp) port number for the telemetry stream destination
                        
                            **type**: int
                        
                                **range:** 0..65535
                        
                        .. attribute:: destination_protocol
                        
                            Protocol used to transmit telemetry data to the collector
                        
                            **type**:  :py:class:`TelemetryStreamProtocol<ydk.models.openconfig.openconfig_telemetry.TelemetryStreamProtocol>`
                        
                        """
                        _prefix = 'oc-telemetry'
                        _revision = '2016-02-04'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "destination"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                ('destination_port', (YLeaf(YType.uint16, 'destination-port'), ['int'])),
                                ('destination_protocol', (YLeaf(YType.enumeration, 'destination-protocol'), [('ydk.models.openconfig.openconfig_telemetry', 'TelemetryStreamProtocol', '')])),
                            ])
                            self.destination_address = None
                            self.destination_port = None
                            self.destination_protocol = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(TelemetrySystem.DestinationGroups.DestinationGroup.Destinations.Destination.Config, ['destination_address', 'destination_port', 'destination_protocol'], name, value)


                    class State(_Entity_):
                        """
                        State information associated with
                        telemetry destinations
                        
                        .. attribute:: destination_address
                        
                            IP address of the telemetry stream destination
                        
                            **type**: union of the below types:
                        
                                **type**: str
                        
                                    **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                                **type**: str
                        
                                    **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                            **config**: False
                        
                        .. attribute:: destination_port
                        
                            Protocol (udp or tcp) port number for the telemetry stream destination
                        
                            **type**: int
                        
                                **range:** 0..65535
                        
                            **config**: False
                        
                        .. attribute:: destination_protocol
                        
                            Protocol used to transmit telemetry data to the collector
                        
                            **type**:  :py:class:`TelemetryStreamProtocol<ydk.models.openconfig.openconfig_telemetry.TelemetryStreamProtocol>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-telemetry'
                        _revision = '2016-02-04'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "destination"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                ('destination_port', (YLeaf(YType.uint16, 'destination-port'), ['int'])),
                                ('destination_protocol', (YLeaf(YType.enumeration, 'destination-protocol'), [('ydk.models.openconfig.openconfig_telemetry', 'TelemetryStreamProtocol', '')])),
                            ])
                            self.destination_address = None
                            self.destination_port = None
                            self.destination_protocol = None
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(TelemetrySystem.DestinationGroups.DestinationGroup.Destinations.Destination.State, ['destination_address', 'destination_port', 'destination_protocol'], name, value)






    class Subscriptions(_Entity_):
        """
        This container holds information for both persistent
        and dynamic telemetry subscriptions.
        
        .. attribute:: persistent
        
            This container holds information relating to persistent telemetry subscriptions. A persistent telemetry subscription is configued locally on the device through configuration, and is persistent across device restarts or other redundancy changes
        
            **type**:  :py:class:`Persistent<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Persistent>`
        
        .. attribute:: dynamic
        
            This container holds information relating to dynamic telemetry subscriptions. A dynamic subscription is typically configured through an RPC channel, and does not persist across device restarts, or if the RPC channel is reset or otherwise torn down
        
            **type**:  :py:class:`Dynamic<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Dynamic>`
        
        """
        _prefix = 'oc-telemetry'
        _revision = '2016-02-04'

        def __init__(self):
            super().__init__()

            self.yang_name = "subscriptions"
            self.yang_parent_name = "telemetry-system"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("persistent", ("persistent", TelemetrySystem.Subscriptions.Persistent)), ("dynamic", ("dynamic", TelemetrySystem.Subscriptions.Dynamic))])
            self._leafs = OrderedDict()

            self.persistent = TelemetrySystem.Subscriptions.Persistent()
            self.persistent.parent = self
            self._children_name_map["persistent"] = "persistent"

            self.dynamic = TelemetrySystem.Subscriptions.Dynamic()
            self.dynamic.parent = self
            self._children_name_map["dynamic"] = "dynamic"
            self._segment_path = lambda: "subscriptions"
            self._absolute_path = lambda: "openconfig-telemetry:telemetry-system/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(TelemetrySystem.Subscriptions, [], name, value)

        class Persistent(_Entity_):
            """
            This container holds information relating to persistent
            telemetry subscriptions. A persistent telemetry
            subscription is configued locally on the device through
            configuration, and is persistent across device restarts or
            other redundancy changes.
            
            .. attribute:: subscription
            
                List of telemetry subscriptions. A telemetry subscription consists of a set of collection destinations, stream attributes, and associated paths to state information in the model (sensor data)
            
                **type**: list of    :py:class:`Subscription<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Persistent.Subscription>`
            
            """
            _prefix = 'oc-telemetry'
            _revision = '2016-02-04'

            def __init__(self):
                super().__init__()

                self.yang_name = "persistent"
                self.yang_parent_name = "subscriptions"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("subscription", ("subscription", TelemetrySystem.Subscriptions.Persistent.Subscription))])
                self._leafs = OrderedDict()

                self.subscription = YList(self)
                self._segment_path = lambda: "persistent"
                self._absolute_path = lambda: "openconfig-telemetry:telemetry-system/subscriptions/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(TelemetrySystem.Subscriptions.Persistent, [], name, value)

            class Subscription(_Entity_):
                """
                List of telemetry subscriptions. A telemetry
                subscription consists of a set of collection
                destinations, stream attributes, and associated paths to
                state information in the model (sensor data)
                
                .. attribute:: subscription_id  (key)
                
                    Reference to the identifier of the subscription itself. The id will be the handle to refer to the subscription once created
                
                    **type**: int
                
                        **range:** 0..18446744073709551615
                
                    **refers to**:  :py:class:`subscription_id<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Persistent.Subscription.Config>`
                
                .. attribute:: config
                
                    Config parameters relating to the telemetry subscriptions on the local device
                
                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Persistent.Subscription.Config>`
                
                .. attribute:: state
                
                    State parameters relating to the telemetry subscriptions on the local device
                
                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Persistent.Subscription.State>`
                
                    **config**: False
                
                .. attribute:: sensor_profiles
                
                    A sensor profile is a set of sensor groups or individual sensor paths which are associated with a telemetry subscription. This is the source of the telemetry data for the subscription to send to the defined collectors
                
                    **type**:  :py:class:`SensorProfiles<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles>`
                
                .. attribute:: destination_groups
                
                    A subscription may specify destination addresses. If the subscription supplies destination addresses, the network element will be the initiator of the telemetry streaming, sending it to the destination(s) specified.  If the destination set is omitted, the subscription preconfigures certain elements such as paths and sample intervals under a specified subscription ID. In this case, the network element will NOT initiate an outbound connection for telemetry, but will wait for an inbound connection from a network management system.  It is expected that the network management system connecting to the network element will reference the preconfigured subscription ID when initiating a subscription
                
                    **type**:  :py:class:`DestinationGroups<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups>`
                
                """
                _prefix = 'oc-telemetry'
                _revision = '2016-02-04'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "subscription"
                    self.yang_parent_name = "persistent"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['subscription_id']
                    self._child_classes = OrderedDict([("config", ("config", TelemetrySystem.Subscriptions.Persistent.Subscription.Config)), ("state", ("state", TelemetrySystem.Subscriptions.Persistent.Subscription.State)), ("sensor-profiles", ("sensor_profiles", TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles)), ("destination-groups", ("destination_groups", TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups))])
                    self._leafs = OrderedDict([
                        ('subscription_id', (YLeaf(YType.str, 'subscription-id'), ['int'])),
                    ])
                    self.subscription_id = None

                    self.config = TelemetrySystem.Subscriptions.Persistent.Subscription.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"

                    self.state = TelemetrySystem.Subscriptions.Persistent.Subscription.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"

                    self.sensor_profiles = TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles()
                    self.sensor_profiles.parent = self
                    self._children_name_map["sensor_profiles"] = "sensor-profiles"

                    self.destination_groups = TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups()
                    self.destination_groups.parent = self
                    self._children_name_map["destination_groups"] = "destination-groups"
                    self._segment_path = lambda: "subscription" + "[subscription-id='" + str(self.subscription_id) + "']"
                    self._absolute_path = lambda: "openconfig-telemetry:telemetry-system/subscriptions/persistent/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(TelemetrySystem.Subscriptions.Persistent.Subscription, ['subscription_id'], name, value)

                class Config(_Entity_):
                    """
                    Config parameters relating to the telemetry
                    subscriptions on the local device
                    
                    .. attribute:: subscription_id
                    
                        Identifer of the telemetry subscription. Will be used by configuration operations needing to modify or delete the telemetry subscription
                    
                        **type**: int
                    
                            **range:** 0..18446744073709551615
                    
                    .. attribute:: local_source_address
                    
                        The IP address which will be the source of packets from the device to a telemetry collector destination
                    
                        **type**: union of the below types:
                    
                            **type**: str
                    
                                **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                            **type**: str
                    
                                **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: originated_qos_marking
                    
                        DSCP marking of packets generated by the telemetry subsystem on the network device
                    
                        **type**: int
                    
                            **range:** 0..63
                    
                    """
                    _prefix = 'oc-telemetry'
                    _revision = '2016-02-04'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "subscription"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('subscription_id', (YLeaf(YType.uint64, 'subscription-id'), ['int'])),
                            ('local_source_address', (YLeaf(YType.str, 'local-source-address'), ['str','str'])),
                            ('originated_qos_marking', (YLeaf(YType.uint8, 'originated-qos-marking'), ['int'])),
                        ])
                        self.subscription_id = None
                        self.local_source_address = None
                        self.originated_qos_marking = None
                        self._segment_path = lambda: "config"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(TelemetrySystem.Subscriptions.Persistent.Subscription.Config, ['subscription_id', 'local_source_address', 'originated_qos_marking'], name, value)


                class State(_Entity_):
                    """
                    State parameters relating to the telemetry
                    subscriptions on the local device
                    
                    .. attribute:: subscription_id
                    
                        Identifer of the telemetry subscription. Will be used by configuration operations needing to modify or delete the telemetry subscription
                    
                        **type**: int
                    
                            **range:** 0..18446744073709551615
                    
                        **config**: False
                    
                    .. attribute:: local_source_address
                    
                        The IP address which will be the source of packets from the device to a telemetry collector destination
                    
                        **type**: union of the below types:
                    
                            **type**: str
                    
                                **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                            **type**: str
                    
                                **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                        **config**: False
                    
                    .. attribute:: originated_qos_marking
                    
                        DSCP marking of packets generated by the telemetry subsystem on the network device
                    
                        **type**: int
                    
                            **range:** 0..63
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-telemetry'
                    _revision = '2016-02-04'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "subscription"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('subscription_id', (YLeaf(YType.uint64, 'subscription-id'), ['int'])),
                            ('local_source_address', (YLeaf(YType.str, 'local-source-address'), ['str','str'])),
                            ('originated_qos_marking', (YLeaf(YType.uint8, 'originated-qos-marking'), ['int'])),
                        ])
                        self.subscription_id = None
                        self.local_source_address = None
                        self.originated_qos_marking = None
                        self._segment_path = lambda: "state"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(TelemetrySystem.Subscriptions.Persistent.Subscription.State, ['subscription_id', 'local_source_address', 'originated_qos_marking'], name, value)


                class SensorProfiles(_Entity_):
                    """
                    A sensor profile is a set of sensor groups or
                    individual sensor paths which are associated with a
                    telemetry subscription. This is the source of the
                    telemetry data for the subscription to send to the
                    defined collectors.
                    
                    .. attribute:: sensor_profile
                    
                        List of telemetry sensor groups used in the subscription
                    
                        **type**: list of    :py:class:`SensorProfile<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles.SensorProfile>`
                    
                    """
                    _prefix = 'oc-telemetry'
                    _revision = '2016-02-04'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "sensor-profiles"
                        self.yang_parent_name = "subscription"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sensor-profile", ("sensor_profile", TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles.SensorProfile))])
                        self._leafs = OrderedDict()

                        self.sensor_profile = YList(self)
                        self._segment_path = lambda: "sensor-profiles"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles, [], name, value)

                    class SensorProfile(_Entity_):
                        """
                        List of telemetry sensor groups used
                        in the subscription
                        
                        .. attribute:: sensor_group  (key)
                        
                            Reference to the telemetry sensor group name
                        
                            **type**: str
                        
                            **refers to**:  :py:class:`sensor_group<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles.SensorProfile.Config>`
                        
                        .. attribute:: config
                        
                            Configuration parameters related to the sensor profile for a subscription
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles.SensorProfile.Config>`
                        
                        .. attribute:: state
                        
                            State information relating to the sensor profile for a subscription
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles.SensorProfile.State>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-telemetry'
                        _revision = '2016-02-04'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "sensor-profile"
                            self.yang_parent_name = "sensor-profiles"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['sensor_group']
                            self._child_classes = OrderedDict([("config", ("config", TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles.SensorProfile.Config)), ("state", ("state", TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles.SensorProfile.State))])
                            self._leafs = OrderedDict([
                                ('sensor_group', (YLeaf(YType.str, 'sensor-group'), ['str'])),
                            ])
                            self.sensor_group = None

                            self.config = TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles.SensorProfile.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles.SensorProfile.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._segment_path = lambda: "sensor-profile" + "[sensor-group='" + str(self.sensor_group) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles.SensorProfile, ['sensor_group'], name, value)

                        class Config(_Entity_):
                            """
                            Configuration parameters related to the sensor
                            profile for a subscription
                            
                            .. attribute:: sensor_group
                            
                                Reference to the sensor group which is used in the profile
                            
                                **type**: str
                            
                                **refers to**:  :py:class:`sensor_group_id<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.SensorGroups.SensorGroup.Config>`
                            
                            .. attribute:: sample_interval
                            
                                Time in milliseconds between the device's sample of a telemetry data source. For example, setting this to 100 would require the local device to collect the telemetry data every 100 milliseconds. There can be latency or jitter in transmitting the data, but the sample must occur at the specified interval.  The timestamp must reflect the actual time when the data was sampled, not simply the previous sample timestamp + sample\-interval.  If sample\-interval is set to 0, the telemetry sensor becomes event based. The sensor must then emit data upon every change of the underlying data source
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                            .. attribute:: heartbeat_interval
                            
                                Maximum time interval in seconds that may pass between updates from a device to a telemetry collector. If this interval expires, but there is no updated data to send (such as if suppress\_updates has been configured), the device must send a telemetry message to the collector
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                            .. attribute:: suppress_redundant
                            
                                Boolean flag to control suppression of redundant telemetry updates to the collector platform. If this flag is set to TRUE, then the collector will only send an update at the configured interval if a subscribed data value has changed. Otherwise, the device will not send an update to the collector until expiration of the heartbeat interval
                            
                                **type**: bool
                            
                            """
                            _prefix = 'oc-telemetry'
                            _revision = '2016-02-04'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "sensor-profile"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sensor_group', (YLeaf(YType.str, 'sensor-group'), ['str'])),
                                    ('sample_interval', (YLeaf(YType.uint64, 'sample-interval'), ['int'])),
                                    ('heartbeat_interval', (YLeaf(YType.uint64, 'heartbeat-interval'), ['int'])),
                                    ('suppress_redundant', (YLeaf(YType.boolean, 'suppress-redundant'), ['bool'])),
                                ])
                                self.sensor_group = None
                                self.sample_interval = None
                                self.heartbeat_interval = None
                                self.suppress_redundant = None
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles.SensorProfile.Config, ['sensor_group', 'sample_interval', 'heartbeat_interval', 'suppress_redundant'], name, value)


                        class State(_Entity_):
                            """
                            State information relating to the sensor profile
                            for a subscription
                            
                            .. attribute:: sensor_group
                            
                                Reference to the sensor group which is used in the profile
                            
                                **type**: str
                            
                                **refers to**:  :py:class:`sensor_group_id<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.SensorGroups.SensorGroup.Config>`
                            
                                **config**: False
                            
                            .. attribute:: sample_interval
                            
                                Time in milliseconds between the device's sample of a telemetry data source. For example, setting this to 100 would require the local device to collect the telemetry data every 100 milliseconds. There can be latency or jitter in transmitting the data, but the sample must occur at the specified interval.  The timestamp must reflect the actual time when the data was sampled, not simply the previous sample timestamp + sample\-interval.  If sample\-interval is set to 0, the telemetry sensor becomes event based. The sensor must then emit data upon every change of the underlying data source
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: heartbeat_interval
                            
                                Maximum time interval in seconds that may pass between updates from a device to a telemetry collector. If this interval expires, but there is no updated data to send (such as if suppress\_updates has been configured), the device must send a telemetry message to the collector
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: suppress_redundant
                            
                                Boolean flag to control suppression of redundant telemetry updates to the collector platform. If this flag is set to TRUE, then the collector will only send an update at the configured interval if a subscribed data value has changed. Otherwise, the device will not send an update to the collector until expiration of the heartbeat interval
                            
                                **type**: bool
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-telemetry'
                            _revision = '2016-02-04'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "sensor-profile"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('sensor_group', (YLeaf(YType.str, 'sensor-group'), ['str'])),
                                    ('sample_interval', (YLeaf(YType.uint64, 'sample-interval'), ['int'])),
                                    ('heartbeat_interval', (YLeaf(YType.uint64, 'heartbeat-interval'), ['int'])),
                                    ('suppress_redundant', (YLeaf(YType.boolean, 'suppress-redundant'), ['bool'])),
                                ])
                                self.sensor_group = None
                                self.sample_interval = None
                                self.heartbeat_interval = None
                                self.suppress_redundant = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(TelemetrySystem.Subscriptions.Persistent.Subscription.SensorProfiles.SensorProfile.State, ['sensor_group', 'sample_interval', 'heartbeat_interval', 'suppress_redundant'], name, value)




                class DestinationGroups(_Entity_):
                    """
                    A subscription may specify destination addresses.
                    If the subscription supplies destination addresses,
                    the network element will be the initiator of the
                    telemetry streaming, sending it to the destination(s)
                    specified.
                    
                    If the destination set is omitted, the subscription
                    preconfigures certain elements such as paths and
                    sample intervals under a specified subscription ID.
                    In this case, the network element will NOT initiate an
                    outbound connection for telemetry, but will wait for
                    an inbound connection from a network management
                    system.
                    
                    It is expected that the network management system
                    connecting to the network element will reference
                    the preconfigured subscription ID when initiating
                    a subscription.
                    
                    .. attribute:: destination_group
                    
                        Identifier of the previously defined destination group
                    
                        **type**: list of    :py:class:`DestinationGroup<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups.DestinationGroup>`
                    
                    """
                    _prefix = 'oc-telemetry'
                    _revision = '2016-02-04'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "destination-groups"
                        self.yang_parent_name = "subscription"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("destination-group", ("destination_group", TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups.DestinationGroup))])
                        self._leafs = OrderedDict()

                        self.destination_group = YList(self)
                        self._segment_path = lambda: "destination-groups"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups, [], name, value)

                    class DestinationGroup(_Entity_):
                        """
                        Identifier of the previously defined destination
                        group
                        
                        .. attribute:: group_id  (key)
                        
                            The destination group id references a configured group of destinations for the telemetry stream
                        
                            **type**: str
                        
                            **refers to**:  :py:class:`group_id<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups.DestinationGroup.Config>`
                        
                        .. attribute:: config
                        
                            Configuration parameters related to telemetry destinations
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups.DestinationGroup.Config>`
                        
                        .. attribute:: state
                        
                            State information related to telemetry destinations
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups.DestinationGroup.State>`
                        
                        """
                        _prefix = 'oc-telemetry'
                        _revision = '2016-02-04'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "destination-group"
                            self.yang_parent_name = "destination-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['group_id']
                            self._child_classes = OrderedDict([("config", ("config", TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups.DestinationGroup.Config)), ("state", ("state", TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups.DestinationGroup.State))])
                            self._leafs = OrderedDict([
                                ('group_id', (YLeaf(YType.str, 'group-id'), ['str'])),
                            ])
                            self.group_id = None

                            self.config = TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups.DestinationGroup.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups.DestinationGroup.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._segment_path = lambda: "destination-group" + "[group-id='" + str(self.group_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups.DestinationGroup, ['group_id'], name, value)

                        class Config(_Entity_):
                            """
                            Configuration parameters related to telemetry
                            destinations.
                            
                            .. attribute:: group_id
                            
                                The destination group id references a reusable group of destination addresses and ports for the telemetry stream
                            
                                **type**: str
                            
                                **refers to**:  :py:class:`group_id<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.DestinationGroups.DestinationGroup>`
                            
                            """
                            _prefix = 'oc-telemetry'
                            _revision = '2016-02-04'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "destination-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group_id', (YLeaf(YType.str, 'group-id'), ['str'])),
                                ])
                                self.group_id = None
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups.DestinationGroup.Config, ['group_id'], name, value)


                        class State(_Entity_):
                            """
                            State information related to telemetry
                            destinations
                            
                            .. attribute:: group_id
                            
                                The destination group id references a reusable group of destination addresses and ports for the telemetry stream
                            
                                **type**: str
                            
                                **refers to**:  :py:class:`group_id<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.DestinationGroups.DestinationGroup>`
                            
                            """
                            _prefix = 'oc-telemetry'
                            _revision = '2016-02-04'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "destination-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('group_id', (YLeaf(YType.str, 'group-id'), ['str'])),
                                ])
                                self.group_id = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(TelemetrySystem.Subscriptions.Persistent.Subscription.DestinationGroups.DestinationGroup.State, ['group_id'], name, value)






        class Dynamic(_Entity_):
            """
            This container holds information relating to dynamic
            telemetry subscriptions. A dynamic subscription is
            typically configured through an RPC channel, and does not
            persist across device restarts, or if the RPC channel is
            reset or otherwise torn down.
            
            .. attribute:: subscription
            
                List representation of telemetry subscriptions that are configured via an inline RPC, otherwise known as dynamic telemetry subscriptions
            
                **type**: list of    :py:class:`Subscription<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Dynamic.Subscription>`
            
                **config**: False
            
            """
            _prefix = 'oc-telemetry'
            _revision = '2016-02-04'

            def __init__(self):
                super().__init__()

                self.yang_name = "dynamic"
                self.yang_parent_name = "subscriptions"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("subscription", ("subscription", TelemetrySystem.Subscriptions.Dynamic.Subscription))])
                self._leafs = OrderedDict()

                self.subscription = YList(self)
                self._segment_path = lambda: "dynamic"
                self._absolute_path = lambda: "openconfig-telemetry:telemetry-system/subscriptions/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(TelemetrySystem.Subscriptions.Dynamic, [], name, value)

            class Subscription(_Entity_):
                """
                List representation of telemetry subscriptions that
                are configured via an inline RPC, otherwise known
                as dynamic telemetry subscriptions.
                
                .. attribute:: subscription_id  (key)
                
                    Reference to the identifier of the subscription itself. The id will be the handle to refer to the subscription once created
                
                    **type**: int
                
                        **range:** 0..18446744073709551615
                
                    **refers to**:  :py:class:`subscription_id<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Dynamic.Subscription.State>`
                
                    **config**: False
                
                .. attribute:: state
                
                    State information relating to dynamic telemetry subscriptions
                
                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Dynamic.Subscription.State>`
                
                    **config**: False
                
                .. attribute:: sensor_paths
                
                    Top level container to hold a set of sensor paths grouped together
                
                    **type**:  :py:class:`SensorPaths<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Dynamic.Subscription.SensorPaths>`
                
                    **config**: False
                
                """
                _prefix = 'oc-telemetry'
                _revision = '2016-02-04'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "subscription"
                    self.yang_parent_name = "dynamic"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['subscription_id']
                    self._child_classes = OrderedDict([("state", ("state", TelemetrySystem.Subscriptions.Dynamic.Subscription.State)), ("sensor-paths", ("sensor_paths", TelemetrySystem.Subscriptions.Dynamic.Subscription.SensorPaths))])
                    self._leafs = OrderedDict([
                        ('subscription_id', (YLeaf(YType.str, 'subscription-id'), ['int'])),
                    ])
                    self.subscription_id = None

                    self.state = TelemetrySystem.Subscriptions.Dynamic.Subscription.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"

                    self.sensor_paths = TelemetrySystem.Subscriptions.Dynamic.Subscription.SensorPaths()
                    self.sensor_paths.parent = self
                    self._children_name_map["sensor_paths"] = "sensor-paths"
                    self._segment_path = lambda: "subscription" + "[subscription-id='" + str(self.subscription_id) + "']"
                    self._absolute_path = lambda: "openconfig-telemetry:telemetry-system/subscriptions/dynamic/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(TelemetrySystem.Subscriptions.Dynamic.Subscription, ['subscription_id'], name, value)

                class State(_Entity_):
                    """
                    State information relating to dynamic telemetry
                    subscriptions.
                    
                    .. attribute:: subscription_id
                    
                        Identifer of the telemetry subscription. Will be used by configuration operations needing to modify or delete the telemetry subscription
                    
                        **type**: int
                    
                            **range:** 0..18446744073709551615
                    
                        **config**: False
                    
                    .. attribute:: destination_address
                    
                        IP address of the telemetry stream destination
                    
                        **type**: union of the below types:
                    
                            **type**: str
                    
                                **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                            **type**: str
                    
                                **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                        **config**: False
                    
                    .. attribute:: destination_port
                    
                        Protocol (udp or tcp) port number for the telemetry stream destination
                    
                        **type**: int
                    
                            **range:** 0..65535
                    
                        **config**: False
                    
                    .. attribute:: destination_protocol
                    
                        Protocol used to transmit telemetry data to the collector
                    
                        **type**:  :py:class:`TelemetryStreamProtocol<ydk.models.openconfig.openconfig_telemetry.TelemetryStreamProtocol>`
                    
                        **config**: False
                    
                    .. attribute:: sample_interval
                    
                        Time in milliseconds between the device's sample of a telemetry data source. For example, setting this to 100 would require the local device to collect the telemetry data every 100 milliseconds. There can be latency or jitter in transmitting the data, but the sample must occur at the specified interval.  The timestamp must reflect the actual time when the data was sampled, not simply the previous sample timestamp + sample\-interval.  If sample\-interval is set to 0, the telemetry sensor becomes event based. The sensor must then emit data upon every change of the underlying data source
                    
                        **type**: int
                    
                            **range:** 0..18446744073709551615
                    
                        **config**: False
                    
                    .. attribute:: heartbeat_interval
                    
                        Maximum time interval in seconds that may pass between updates from a device to a telemetry collector. If this interval expires, but there is no updated data to send (such as if suppress\_updates has been configured), the device must send a telemetry message to the collector
                    
                        **type**: int
                    
                            **range:** 0..18446744073709551615
                    
                        **config**: False
                    
                    .. attribute:: suppress_redundant
                    
                        Boolean flag to control suppression of redundant telemetry updates to the collector platform. If this flag is set to TRUE, then the collector will only send an update at the configured interval if a subscribed data value has changed. Otherwise, the device will not send an update to the collector until expiration of the heartbeat interval
                    
                        **type**: bool
                    
                        **config**: False
                    
                    .. attribute:: originated_qos_marking
                    
                        DSCP marking of packets generated by the telemetry subsystem on the network device
                    
                        **type**: int
                    
                            **range:** 0..63
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-telemetry'
                    _revision = '2016-02-04'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "subscription"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('subscription_id', (YLeaf(YType.uint64, 'subscription-id'), ['int'])),
                            ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                            ('destination_port', (YLeaf(YType.uint16, 'destination-port'), ['int'])),
                            ('destination_protocol', (YLeaf(YType.enumeration, 'destination-protocol'), [('ydk.models.openconfig.openconfig_telemetry', 'TelemetryStreamProtocol', '')])),
                            ('sample_interval', (YLeaf(YType.uint64, 'sample-interval'), ['int'])),
                            ('heartbeat_interval', (YLeaf(YType.uint64, 'heartbeat-interval'), ['int'])),
                            ('suppress_redundant', (YLeaf(YType.boolean, 'suppress-redundant'), ['bool'])),
                            ('originated_qos_marking', (YLeaf(YType.uint8, 'originated-qos-marking'), ['int'])),
                        ])
                        self.subscription_id = None
                        self.destination_address = None
                        self.destination_port = None
                        self.destination_protocol = None
                        self.sample_interval = None
                        self.heartbeat_interval = None
                        self.suppress_redundant = None
                        self.originated_qos_marking = None
                        self._segment_path = lambda: "state"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(TelemetrySystem.Subscriptions.Dynamic.Subscription.State, ['subscription_id', 'destination_address', 'destination_port', 'destination_protocol', 'sample_interval', 'heartbeat_interval', 'suppress_redundant', 'originated_qos_marking'], name, value)


                class SensorPaths(_Entity_):
                    """
                    Top level container to hold a set of sensor
                    paths grouped together
                    
                    .. attribute:: sensor_path
                    
                        List of paths in the model which together comprise a sensor grouping. Filters for each path to exclude items are also provided
                    
                        **type**: list of    :py:class:`SensorPath<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Dynamic.Subscription.SensorPaths.SensorPath>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-telemetry'
                    _revision = '2016-02-04'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "sensor-paths"
                        self.yang_parent_name = "subscription"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sensor-path", ("sensor_path", TelemetrySystem.Subscriptions.Dynamic.Subscription.SensorPaths.SensorPath))])
                        self._leafs = OrderedDict()

                        self.sensor_path = YList(self)
                        self._segment_path = lambda: "sensor-paths"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(TelemetrySystem.Subscriptions.Dynamic.Subscription.SensorPaths, [], name, value)

                    class SensorPath(_Entity_):
                        """
                        List of paths in the model which together
                        comprise a sensor grouping. Filters for each path
                        to exclude items are also provided.
                        
                        .. attribute:: path  (key)
                        
                            Reference to the path of interest
                        
                            **type**: str
                        
                            **refers to**:  :py:class:`path<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Dynamic.Subscription.SensorPaths.SensorPath.State>`
                        
                            **config**: False
                        
                        .. attribute:: state
                        
                            State information for a dynamic subscription's paths of interest
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_telemetry.TelemetrySystem.Subscriptions.Dynamic.Subscription.SensorPaths.SensorPath.State>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-telemetry'
                        _revision = '2016-02-04'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "sensor-path"
                            self.yang_parent_name = "sensor-paths"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['path']
                            self._child_classes = OrderedDict([("state", ("state", TelemetrySystem.Subscriptions.Dynamic.Subscription.SensorPaths.SensorPath.State))])
                            self._leafs = OrderedDict([
                                ('path', (YLeaf(YType.str, 'path'), ['str'])),
                            ])
                            self.path = None

                            self.state = TelemetrySystem.Subscriptions.Dynamic.Subscription.SensorPaths.SensorPath.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._segment_path = lambda: "sensor-path" + "[path='" + str(self.path) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(TelemetrySystem.Subscriptions.Dynamic.Subscription.SensorPaths.SensorPath, ['path'], name, value)

                        class State(_Entity_):
                            """
                            State information for a dynamic subscription's
                            paths of interest
                            
                            .. attribute:: path
                            
                                Path to a section of operational state of interest (the sensor)
                            
                                **type**: str
                            
                                **config**: False
                            
                            .. attribute:: exclude_filter
                            
                                Filter to exclude certain values out of the state values
                            
                                **type**: str
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-telemetry'
                            _revision = '2016-02-04'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "sensor-path"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('path', (YLeaf(YType.str, 'path'), ['str'])),
                                    ('exclude_filter', (YLeaf(YType.str, 'exclude-filter'), ['str'])),
                                ])
                                self.path = None
                                self.exclude_filter = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(TelemetrySystem.Subscriptions.Dynamic.Subscription.SensorPaths.SensorPath.State, ['path', 'exclude_filter'], name, value)







    def clone_ptr(self):
        self._top_entity = TelemetrySystem()
        return self._top_entity






""" openconfig_aft_types 

Types related to the OpenConfig Abstract Forwarding
Table (AFT) model

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class EncapsulationHeaderType(Enum):
    """
    EncapsulationHeaderType (Enum Class)

    Types of tunnel encapsulation that are supported by systems as either

    head\- or tail\-end.

    .. data:: GRE = 0

        The encapsulation header is a Generic Routing Encapsulation

        header.

    .. data:: IPV4 = 1

        The encapsulation header is an IPv4 packet header

    .. data:: IPV6 = 2

        The encapsulation header is an IPv6 packet header

    .. data:: MPLS = 3

        The encapsulation header is one or more MPLS labels indicated

        by the pushed and popped label stack lists.

    """

    GRE = Enum.YLeaf(0, "GRE")

    IPV4 = Enum.YLeaf(1, "IPV4")

    IPV6 = Enum.YLeaf(2, "IPV6")

    MPLS = Enum.YLeaf(3, "MPLS")






""" openconfig_isis_types 

This module contains general data definitions for use in ISIS YANG
model.

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class AdaptiveTimerType(Enum):
    """
    AdaptiveTimerType (Enum Class)

    This type defines ISIS adaptive timer types

    .. data:: LINEAR = 0

        This enum describes linear algorithm timer

    .. data:: EXPONENTIAL = 1

        This enum describes exponential algorithm timer

    """

    LINEAR = Enum.YLeaf(0, "LINEAR")

    EXPONENTIAL = Enum.YLeaf(1, "EXPONENTIAL")


class CircuitType(Enum):
    """
    CircuitType (Enum Class)

    This type defines ISIS interface types 

    .. data:: POINT_TO_POINT = 0

        This enum describes a point-to-point interface

    .. data:: BROADCAST = 1

        This enum describes a broadcast interface

    """

    POINT_TO_POINT = Enum.YLeaf(0, "POINT_TO_POINT")

    BROADCAST = Enum.YLeaf(1, "BROADCAST")


class HelloPaddingType(Enum):
    """
    HelloPaddingType (Enum Class)

    This type defines ISIS hello padding type

    .. data:: STRICT = 0

        This enum describes strict padding

    .. data:: LOOSE = 1

        This enum describes loose padding

    .. data:: ADAPTIVE = 2

        This enum describes adaptive padding

    .. data:: DISABLE = 3

        This enum disables padding

    """

    STRICT = Enum.YLeaf(0, "STRICT")

    LOOSE = Enum.YLeaf(1, "LOOSE")

    ADAPTIVE = Enum.YLeaf(2, "ADAPTIVE")

    DISABLE = Enum.YLeaf(3, "DISABLE")


class IsisInterfaceAdjState(Enum):
    """
    IsisInterfaceAdjState (Enum Class)

    This type defines the state of the interface.

    .. data:: UP = 0

        This state describes that adjacency is established.

    .. data:: DOWN = 1

        This state describes that adjacency is NOT established.

    .. data:: INIT = 2

        This state describes that adjacency is establishing.

    .. data:: FAILED = 3

        This state describes that adjacency is failed.

    """

    UP = Enum.YLeaf(0, "UP")

    DOWN = Enum.YLeaf(1, "DOWN")

    INIT = Enum.YLeaf(2, "INIT")

    FAILED = Enum.YLeaf(3, "FAILED")


class LevelType(Enum):
    """
    LevelType (Enum Class)

    This type defines ISIS level types

    .. data:: LEVEL_1 = 0

        This enum describes ISIS level 1

    .. data:: LEVEL_2 = 1

        This enum describes ISIS level 2

    .. data:: LEVEL_1_2 = 2

        This enum describes ISIS level 1-2

    """

    LEVEL_1 = Enum.YLeaf(0, "LEVEL_1")

    LEVEL_2 = Enum.YLeaf(1, "LEVEL_2")

    LEVEL_1_2 = Enum.YLeaf(2, "LEVEL_1_2")


class MetricStyle(Enum):
    """
    MetricStyle (Enum Class)

    This type defines ISIS metric styles

    .. data:: NARROW_METRIC = 0

        This enum describes narrow metric style

    .. data:: WIDE_METRIC = 1

        This enum describes wide metric style

    """

    NARROW_METRIC = Enum.YLeaf(0, "NARROW_METRIC")

    WIDE_METRIC = Enum.YLeaf(1, "WIDE_METRIC")


class MetricType(Enum):
    """
    MetricType (Enum Class)

    This type defines ISIS metric type

    .. data:: INTERNAL = 0

        This enum describes internal route type

    .. data:: EXTERNAL = 1

        This enum describes external route type

    """

    INTERNAL = Enum.YLeaf(0, "INTERNAL")

    EXTERNAL = Enum.YLeaf(1, "EXTERNAL")


class OVERLOADRESETTRIGGERTYPE(Identity):
    """
    Base identify type for triggers that reset Overload Bit
    
    """
    _prefix = 'oc-isis-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-types", pref="openconfig-isis-types", tag="openconfig-isis-types:OVERLOAD_RESET_TRIGGER_TYPE"):
        super().__init__(ns, pref, tag)


class MTTYPE(Identity):
    """
    Base identify type for multi\-topology
    
    """
    _prefix = 'oc-isis-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-types", pref="openconfig-isis-types", tag="openconfig-isis-types:MT_TYPE"):
        super().__init__(ns, pref, tag)


class SAFITYPE(Identity):
    """
    Base identify type for SAFI
    
    """
    _prefix = 'oc-isis-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-types", pref="openconfig-isis-types", tag="openconfig-isis-types:SAFI_TYPE"):
        super().__init__(ns, pref, tag)


class AFITYPE(Identity):
    """
    Base identify type for AFI
    
    """
    _prefix = 'oc-isis-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-types", pref="openconfig-isis-types", tag="openconfig-isis-types:AFI_TYPE"):
        super().__init__(ns, pref, tag)


class AFISAFITYPE(Identity):
    """
    Base identify type for AFI/SAFI
    
    """
    _prefix = 'oc-isis-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-types", pref="openconfig-isis-types", tag="openconfig-isis-types:AFI_SAFI_TYPE"):
        super().__init__(ns, pref, tag)


class WAITFORBGP(OVERLOADRESETTRIGGERTYPE):
    """
    Base identity type for resetting Overload Bit when BGP has converged. 
    
    """
    _prefix = 'oc-isis-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-types", pref="openconfig-isis-types", tag="openconfig-isis-types:WAIT_FOR_BGP"):
        super().__init__(ns, pref, tag)


class WAITFORSYSTEM(OVERLOADRESETTRIGGERTYPE):
    """
    Base identity type for resetting Overload Bit when system resources have
    been restored. 
    
    """
    _prefix = 'oc-isis-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-types", pref="openconfig-isis-types", tag="openconfig-isis-types:WAIT_FOR_SYSTEM"):
        super().__init__(ns, pref, tag)


class IPV4UNICAST(AFISAFITYPE):
    """
    Base identify type for IPv4 Unicast address family
    
    """
    _prefix = 'oc-isis-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-types", pref="openconfig-isis-types", tag="openconfig-isis-types:IPV4_UNICAST"):
        super().__init__(ns, pref, tag)


class IPV6MULTICAST(AFISAFITYPE):
    """
    Base identify type for IPv6 multicast address family
    
    """
    _prefix = 'oc-isis-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-types", pref="openconfig-isis-types", tag="openconfig-isis-types:IPV6_MULTICAST"):
        super().__init__(ns, pref, tag)


class IPV4MULTICAST(AFISAFITYPE):
    """
    Base identify type for IPv4 multicast address family
    
    """
    _prefix = 'oc-isis-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-types", pref="openconfig-isis-types", tag="openconfig-isis-types:IPV4_MULTICAST"):
        super().__init__(ns, pref, tag)


class IPV6UNICAST(AFISAFITYPE):
    """
    Base identify type for IPv6 unicast address family
    
    """
    _prefix = 'oc-isis-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-types", pref="openconfig-isis-types", tag="openconfig-isis-types:IPV6_UNICAST"):
        super().__init__(ns, pref, tag)


class UNICAST(SAFITYPE):
    """
    Base identify type for IPv4 Unicast address family
    
    """
    _prefix = 'oc-isis-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-types", pref="openconfig-isis-types", tag="openconfig-isis-types:UNICAST"):
        super().__init__(ns, pref, tag)


class MULTICAST(SAFITYPE):
    """
    Base identify type for IPv6 multicast address family
    
    """
    _prefix = 'oc-isis-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-types", pref="openconfig-isis-types", tag="openconfig-isis-types:MULTICAST"):
        super().__init__(ns, pref, tag)


class IPV4(AFITYPE):
    """
    Base identify type for IPv4 address family
    
    """
    _prefix = 'oc-isis-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-types", pref="openconfig-isis-types", tag="openconfig-isis-types:IPV4"):
        super().__init__(ns, pref, tag)


class IPV6(AFITYPE):
    """
    Base identify type for IPv6 address family
    
    """
    _prefix = 'oc-isis-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-types", pref="openconfig-isis-types", tag="openconfig-isis-types:IPV6"):
        super().__init__(ns, pref, tag)






""" openconfig_isis 

This module describes a YANG model for ISIS protocol configuration.
It is a limited subset of all of the configuration parameters
available in the variety of vendor implementations, hence it is
expected that it would be augmented with vendor \- specific configuration
data as needed. Additional modules or submodules to handle other
aspects of ISIS configuration, including policy, routing, types,
LSDB and additional address families are also expected. This model
supports the following ISIS configuration level hierarchy\:

ISIS
+\-> { global ISIS configuration}
   +\-> levels +\-> { level config}
       +\-> { system\-level\-counters }
       +\-> { level link\-state\-database}
   +\-> interface +\-> { interface config }
       +\-> { circuit\-counters }
       +\-> { levels config }
       +\-> { level adjacencies }

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class IsisMetricFlags(Enum):
    """
    IsisMetricFlags (Enum Class)

    Type definition for flags used in IS\-IS metrics

    .. data:: INTERNAL = 0

        When this flag is not set, internal metrics are in use.

    .. data:: UNSUPPORTED = 1

        When this flag (referred to as the S-bit) is set, then

        the metric is unsupported.

    """

    INTERNAL = Enum.YLeaf(0, "INTERNAL")

    UNSUPPORTED = Enum.YLeaf(1, "UNSUPPORTED")






""" openconfig_lldp 

This module defines configuration and operational state data
for the LLDP protocol.

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class Lldp(_Entity_):
    """
    Top\-level container for LLDP configuration and state data
    
    .. attribute:: config
    
        Configuration data 
    
        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_lldp.Lldp.Config>`
    
    .. attribute:: state
    
        Operational state data 
    
        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_lldp.Lldp.State>`
    
        **config**: False
    
    .. attribute:: interfaces
    
        Enclosing container 
    
        **type**:  :py:class:`Interfaces<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces>`
    
    """
    _prefix = 'oc-lldp'
    _revision = '2016-05-16'

    def __init__(self):
        super().__init__()
        self._top_entity = None

        self.yang_name = "lldp"
        self.yang_parent_name = "openconfig-lldp"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("config", ("config", Lldp.Config)), ("state", ("state", Lldp.State)), ("interfaces", ("interfaces", Lldp.Interfaces))])
        self._leafs = OrderedDict()

        self.config = Lldp.Config()
        self.config.parent = self
        self._children_name_map["config"] = "config"

        self.state = Lldp.State()
        self.state.parent = self
        self._children_name_map["state"] = "state"

        self.interfaces = Lldp.Interfaces()
        self.interfaces.parent = self
        self._children_name_map["interfaces"] = "interfaces"
        self._segment_path = lambda: "openconfig-lldp:lldp"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(Lldp, [], name, value)

    class Config(_Entity_):
        """
        Configuration data 
        
        .. attribute:: enabled
        
            System level state of the LLDP protocol
        
            **type**: bool
        
            **default value**: true
        
        .. attribute:: hello_timer
        
            System level hello timer for the LLDP protocol
        
            **type**: int
        
                **range:** 0..18446744073709551615
        
            **units**: seconds
        
        .. attribute:: suppress_tlv_advertisement
        
            Indicates whether the local system should suppress the advertisement of particular TLVs with the LLDP PDUs that it transmits. Where a TLV type is specified within this list, it should not be included in any LLDP PDU transmitted by the local agent
        
            **type**: list of   :py:class:`LLDPTLV<ydk.models.openconfig.openconfig_lldp_types.LLDPTLV>`
        
        .. attribute:: system_name
        
            The system name field shall contain an alpha\-numeric string that indicates the system's administratively assigned name. The system name should be the system's fully qualified domain name. If implementations support IETF RFC 3418, the sysName object should be used for this field
        
            **type**: str
        
                **length:** 0..255
        
        .. attribute:: system_description
        
            The system description field shall contain an alpha\-numeric string that is the textual description of the network entity. The system description should include the full name and version identification of the system's hardware type, software operating system, and networking software. If implementations support IETF RFC 3418, the sysDescr object should be used for this field
        
            **type**: str
        
                **length:** 0..255
        
        .. attribute:: chassis_id
        
            The Chassis ID is a mandatory TLV which identifies the chassis component of the endpoint identifier associated with the transmitting LLDP agent
        
            **type**: str
        
        .. attribute:: chassis_id_type
        
            This field identifies the format and source of the chassis identifier string. It is an enumerator defined by the LldpChassisIdSubtype object from IEEE 802.1AB MIB
        
            **type**:  :py:class:`ChassisIdType<ydk.models.openconfig.openconfig_lldp_types.ChassisIdType>`
        
        """
        _prefix = 'oc-lldp'
        _revision = '2016-05-16'

        def __init__(self):
            super().__init__()

            self.yang_name = "config"
            self.yang_parent_name = "lldp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                ('hello_timer', (YLeaf(YType.uint64, 'hello-timer'), ['int'])),
                ('suppress_tlv_advertisement', (YLeafList(YType.identityref, 'suppress-tlv-advertisement'), [('ydk.models.openconfig.openconfig_lldp_types', 'LLDPTLV')])),
                ('system_name', (YLeaf(YType.str, 'system-name'), ['str'])),
                ('system_description', (YLeaf(YType.str, 'system-description'), ['str'])),
                ('chassis_id', (YLeaf(YType.str, 'chassis-id'), ['str'])),
                ('chassis_id_type', (YLeaf(YType.enumeration, 'chassis-id-type'), [('ydk.models.openconfig.openconfig_lldp_types', 'ChassisIdType', '')])),
            ])
            self.enabled = None
            self.hello_timer = None
            self.suppress_tlv_advertisement = []
            self.system_name = None
            self.system_description = None
            self.chassis_id = None
            self.chassis_id_type = None
            self._segment_path = lambda: "config"
            self._absolute_path = lambda: "openconfig-lldp:lldp/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Lldp.Config, ['enabled', 'hello_timer', 'suppress_tlv_advertisement', 'system_name', 'system_description', 'chassis_id', 'chassis_id_type'], name, value)


    class State(_Entity_):
        """
        Operational state data 
        
        .. attribute:: enabled
        
            System level state of the LLDP protocol
        
            **type**: bool
        
            **config**: False
        
            **default value**: true
        
        .. attribute:: hello_timer
        
            System level hello timer for the LLDP protocol
        
            **type**: int
        
                **range:** 0..18446744073709551615
        
            **config**: False
        
            **units**: seconds
        
        .. attribute:: suppress_tlv_advertisement
        
            Indicates whether the local system should suppress the advertisement of particular TLVs with the LLDP PDUs that it transmits. Where a TLV type is specified within this list, it should not be included in any LLDP PDU transmitted by the local agent
        
            **type**: list of   :py:class:`LLDPTLV<ydk.models.openconfig.openconfig_lldp_types.LLDPTLV>`
        
            **config**: False
        
        .. attribute:: system_name
        
            The system name field shall contain an alpha\-numeric string that indicates the system's administratively assigned name. The system name should be the system's fully qualified domain name. If implementations support IETF RFC 3418, the sysName object should be used for this field
        
            **type**: str
        
                **length:** 0..255
        
            **config**: False
        
        .. attribute:: system_description
        
            The system description field shall contain an alpha\-numeric string that is the textual description of the network entity. The system description should include the full name and version identification of the system's hardware type, software operating system, and networking software. If implementations support IETF RFC 3418, the sysDescr object should be used for this field
        
            **type**: str
        
                **length:** 0..255
        
            **config**: False
        
        .. attribute:: chassis_id
        
            The Chassis ID is a mandatory TLV which identifies the chassis component of the endpoint identifier associated with the transmitting LLDP agent
        
            **type**: str
        
            **config**: False
        
        .. attribute:: chassis_id_type
        
            This field identifies the format and source of the chassis identifier string. It is an enumerator defined by the LldpChassisIdSubtype object from IEEE 802.1AB MIB
        
            **type**:  :py:class:`ChassisIdType<ydk.models.openconfig.openconfig_lldp_types.ChassisIdType>`
        
            **config**: False
        
        .. attribute:: counters
        
            Global LLDP counters
        
            **type**:  :py:class:`Counters<ydk.models.openconfig.openconfig_lldp.Lldp.State.Counters>`
        
            **config**: False
        
        """
        _prefix = 'oc-lldp'
        _revision = '2016-05-16'

        def __init__(self):
            super().__init__()

            self.yang_name = "state"
            self.yang_parent_name = "lldp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("counters", ("counters", Lldp.State.Counters))])
            self._leafs = OrderedDict([
                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                ('hello_timer', (YLeaf(YType.uint64, 'hello-timer'), ['int'])),
                ('suppress_tlv_advertisement', (YLeafList(YType.identityref, 'suppress-tlv-advertisement'), [('ydk.models.openconfig.openconfig_lldp_types', 'LLDPTLV')])),
                ('system_name', (YLeaf(YType.str, 'system-name'), ['str'])),
                ('system_description', (YLeaf(YType.str, 'system-description'), ['str'])),
                ('chassis_id', (YLeaf(YType.str, 'chassis-id'), ['str'])),
                ('chassis_id_type', (YLeaf(YType.enumeration, 'chassis-id-type'), [('ydk.models.openconfig.openconfig_lldp_types', 'ChassisIdType', '')])),
            ])
            self.enabled = None
            self.hello_timer = None
            self.suppress_tlv_advertisement = []
            self.system_name = None
            self.system_description = None
            self.chassis_id = None
            self.chassis_id_type = None

            self.counters = Lldp.State.Counters()
            self.counters.parent = self
            self._children_name_map["counters"] = "counters"
            self._segment_path = lambda: "state"
            self._absolute_path = lambda: "openconfig-lldp:lldp/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Lldp.State, ['enabled', 'hello_timer', 'suppress_tlv_advertisement', 'system_name', 'system_description', 'chassis_id', 'chassis_id_type'], name, value)

        class Counters(_Entity_):
            """
            Global LLDP counters
            
            .. attribute:: frame_in
            
                The number of lldp frames received
            
                **type**: int
            
                    **range:** 0..18446744073709551615
            
                **config**: False
            
            .. attribute:: frame_out
            
                The number of frames transmitted out
            
                **type**: int
            
                    **range:** 0..18446744073709551615
            
                **config**: False
            
            .. attribute:: frame_error_in
            
                The number of LLDP frames received with errors
            
                **type**: int
            
                    **range:** 0..18446744073709551615
            
                **config**: False
            
            .. attribute:: frame_discard
            
                The number of LLDP frames received and discarded
            
                **type**: int
            
                    **range:** 0..18446744073709551615
            
                **config**: False
            
            .. attribute:: tlv_discard
            
                The number of TLV frames received and discarded
            
                **type**: int
            
                    **range:** 0..18446744073709551615
            
                **config**: False
            
            .. attribute:: tlv_unknown
            
                The number of frames received with unknown TLV
            
                **type**: int
            
                    **range:** 0..18446744073709551615
            
                **config**: False
            
            .. attribute:: last_clear
            
                Indicates the last time the counters were cleared
            
                **type**: str
            
                    **pattern:** \\d{4}\-\\d{2}\-\\d{2}T\\d{2}\:\\d{2}\:\\d{2}(\\.\\d+)?(Z\|[\\+\\\-]\\d{2}\:\\d{2})
            
                **config**: False
            
            .. attribute:: tlv_accepted
            
                The number of valid TLVs received
            
                **type**: int
            
                    **range:** 0..18446744073709551615
            
                **config**: False
            
            .. attribute:: entries_aged_out
            
                The number of entries aged out due to timeout
            
                **type**: int
            
                    **range:** 0..18446744073709551615
            
                **config**: False
            
            """
            _prefix = 'oc-lldp'
            _revision = '2016-05-16'

            def __init__(self):
                super().__init__()

                self.yang_name = "counters"
                self.yang_parent_name = "state"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('frame_in', (YLeaf(YType.uint64, 'frame-in'), ['int'])),
                    ('frame_out', (YLeaf(YType.uint64, 'frame-out'), ['int'])),
                    ('frame_error_in', (YLeaf(YType.uint64, 'frame-error-in'), ['int'])),
                    ('frame_discard', (YLeaf(YType.uint64, 'frame-discard'), ['int'])),
                    ('tlv_discard', (YLeaf(YType.uint64, 'tlv-discard'), ['int'])),
                    ('tlv_unknown', (YLeaf(YType.uint64, 'tlv-unknown'), ['int'])),
                    ('last_clear', (YLeaf(YType.str, 'last-clear'), ['str'])),
                    ('tlv_accepted', (YLeaf(YType.uint64, 'tlv-accepted'), ['int'])),
                    ('entries_aged_out', (YLeaf(YType.uint64, 'entries-aged-out'), ['int'])),
                ])
                self.frame_in = None
                self.frame_out = None
                self.frame_error_in = None
                self.frame_discard = None
                self.tlv_discard = None
                self.tlv_unknown = None
                self.last_clear = None
                self.tlv_accepted = None
                self.entries_aged_out = None
                self._segment_path = lambda: "counters"
                self._absolute_path = lambda: "openconfig-lldp:lldp/state/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Lldp.State.Counters, ['frame_in', 'frame_out', 'frame_error_in', 'frame_discard', 'tlv_discard', 'tlv_unknown', 'last_clear', 'tlv_accepted', 'entries_aged_out'], name, value)



    class Interfaces(_Entity_):
        """
        Enclosing container 
        
        .. attribute:: interface
        
            List of interfaces on which LLDP is enabled / available
        
            **type**: list of    :py:class:`Interface<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface>`
        
        """
        _prefix = 'oc-lldp'
        _revision = '2016-05-16'

        def __init__(self):
            super().__init__()

            self.yang_name = "interfaces"
            self.yang_parent_name = "lldp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("interface", ("interface", Lldp.Interfaces.Interface))])
            self._leafs = OrderedDict()

            self.interface = YList(self)
            self._segment_path = lambda: "interfaces"
            self._absolute_path = lambda: "openconfig-lldp:lldp/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Lldp.Interfaces, [], name, value)

        class Interface(_Entity_):
            """
            List of interfaces on which LLDP is enabled / available
            
            .. attribute:: name  (key)
            
                Reference to the list key
            
                **type**: str
            
                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Config>`
            
            .. attribute:: config
            
                Configuration data for LLDP on each interface
            
                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Config>`
            
            .. attribute:: state
            
                Operational state data 
            
                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.State>`
            
                **config**: False
            
            .. attribute:: neighbors
            
                Enclosing container for list of LLDP neighbors on an interface
            
                **type**:  :py:class:`Neighbors<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors>`
            
                **config**: False
            
            """
            _prefix = 'oc-lldp'
            _revision = '2016-05-16'

            def __init__(self):
                super().__init__()

                self.yang_name = "interface"
                self.yang_parent_name = "interfaces"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("config", ("config", Lldp.Interfaces.Interface.Config)), ("state", ("state", Lldp.Interfaces.Interface.State)), ("neighbors", ("neighbors", Lldp.Interfaces.Interface.Neighbors))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.name = None

                self.config = Lldp.Interfaces.Interface.Config()
                self.config.parent = self
                self._children_name_map["config"] = "config"

                self.state = Lldp.Interfaces.Interface.State()
                self.state.parent = self
                self._children_name_map["state"] = "state"

                self.neighbors = Lldp.Interfaces.Interface.Neighbors()
                self.neighbors.parent = self
                self._children_name_map["neighbors"] = "neighbors"
                self._segment_path = lambda: "interface" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "openconfig-lldp:lldp/interfaces/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Lldp.Interfaces.Interface, ['name'], name, value)

            class Config(_Entity_):
                """
                Configuration data for LLDP on each interface
                
                .. attribute:: name
                
                    Reference to the LLDP Ethernet interface
                
                    **type**: str
                
                    **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                
                .. attribute:: enabled
                
                    Enable or disable the LLDP protocol on the interface
                
                    **type**: bool
                
                    **default value**: true
                
                .. attribute:: snooping
                
                    If true, LLDP PDUs are only received and processed on the interface, but are not originated by the local agent. The PDUs are not dropped by the interface after processing, but relayed to the downstream link layer neighbors. If false, LLDP PDUs are both received and originated on the interface. The snooping mode is valid only when LLDP is enabled on the interface. The snooping mode is useful when an interface does not want its link layer neighbors to discover itself since, for example, it is a lower\-layer interface
                
                    **type**: bool
                
                    **default value**: false
                
                """
                _prefix = 'oc-lldp'
                _revision = '2016-05-16'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "config"
                    self.yang_parent_name = "interface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('snooping', (YLeaf(YType.boolean, 'openconfig-terminal-device:snooping'), ['bool'])),
                    ])
                    self.name = None
                    self.enabled = None
                    self.snooping = None
                    self._segment_path = lambda: "config"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Lldp.Interfaces.Interface.Config, ['name', 'enabled', 'snooping'], name, value)


            class State(_Entity_):
                """
                Operational state data 
                
                .. attribute:: name
                
                    Reference to the LLDP Ethernet interface
                
                    **type**: str
                
                    **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                
                    **config**: False
                
                .. attribute:: enabled
                
                    Enable or disable the LLDP protocol on the interface
                
                    **type**: bool
                
                    **config**: False
                
                    **default value**: true
                
                .. attribute:: counters
                
                    LLDP counters on each interface
                
                    **type**:  :py:class:`Counters<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.State.Counters>`
                
                    **config**: False
                
                """
                _prefix = 'oc-lldp'
                _revision = '2016-05-16'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "state"
                    self.yang_parent_name = "interface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("counters", ("counters", Lldp.Interfaces.Interface.State.Counters))])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                    ])
                    self.name = None
                    self.enabled = None

                    self.counters = Lldp.Interfaces.Interface.State.Counters()
                    self.counters.parent = self
                    self._children_name_map["counters"] = "counters"
                    self._segment_path = lambda: "state"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Lldp.Interfaces.Interface.State, ['name', 'enabled'], name, value)

                class Counters(_Entity_):
                    """
                    LLDP counters on each interface
                    
                    .. attribute:: frame_in
                    
                        The number of lldp frames received
                    
                        **type**: int
                    
                            **range:** 0..18446744073709551615
                    
                        **config**: False
                    
                    .. attribute:: frame_out
                    
                        The number of frames transmitted out
                    
                        **type**: int
                    
                            **range:** 0..18446744073709551615
                    
                        **config**: False
                    
                    .. attribute:: frame_error_in
                    
                        The number of LLDP frames received with errors
                    
                        **type**: int
                    
                            **range:** 0..18446744073709551615
                    
                        **config**: False
                    
                    .. attribute:: frame_discard
                    
                        The number of LLDP frames received and discarded
                    
                        **type**: int
                    
                            **range:** 0..18446744073709551615
                    
                        **config**: False
                    
                    .. attribute:: tlv_discard
                    
                        The number of TLV frames received and discarded
                    
                        **type**: int
                    
                            **range:** 0..18446744073709551615
                    
                        **config**: False
                    
                    .. attribute:: tlv_unknown
                    
                        The number of frames received with unknown TLV
                    
                        **type**: int
                    
                            **range:** 0..18446744073709551615
                    
                        **config**: False
                    
                    .. attribute:: last_clear
                    
                        Indicates the last time the counters were cleared
                    
                        **type**: str
                    
                            **pattern:** \\d{4}\-\\d{2}\-\\d{2}T\\d{2}\:\\d{2}\:\\d{2}(\\.\\d+)?(Z\|[\\+\\\-]\\d{2}\:\\d{2})
                    
                        **config**: False
                    
                    .. attribute:: frame_error_out
                    
                        The number of frame transmit errors on the interface
                    
                        **type**: int
                    
                            **range:** 0..18446744073709551615
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-lldp'
                    _revision = '2016-05-16'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "counters"
                        self.yang_parent_name = "state"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('frame_in', (YLeaf(YType.uint64, 'frame-in'), ['int'])),
                            ('frame_out', (YLeaf(YType.uint64, 'frame-out'), ['int'])),
                            ('frame_error_in', (YLeaf(YType.uint64, 'frame-error-in'), ['int'])),
                            ('frame_discard', (YLeaf(YType.uint64, 'frame-discard'), ['int'])),
                            ('tlv_discard', (YLeaf(YType.uint64, 'tlv-discard'), ['int'])),
                            ('tlv_unknown', (YLeaf(YType.uint64, 'tlv-unknown'), ['int'])),
                            ('last_clear', (YLeaf(YType.str, 'last-clear'), ['str'])),
                            ('frame_error_out', (YLeaf(YType.uint64, 'frame-error-out'), ['int'])),
                        ])
                        self.frame_in = None
                        self.frame_out = None
                        self.frame_error_in = None
                        self.frame_discard = None
                        self.tlv_discard = None
                        self.tlv_unknown = None
                        self.last_clear = None
                        self.frame_error_out = None
                        self._segment_path = lambda: "counters"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Lldp.Interfaces.Interface.State.Counters, ['frame_in', 'frame_out', 'frame_error_in', 'frame_discard', 'tlv_discard', 'tlv_unknown', 'last_clear', 'frame_error_out'], name, value)



            class Neighbors(_Entity_):
                """
                Enclosing container for list of LLDP neighbors on an
                interface
                
                .. attribute:: neighbor
                
                    List of LLDP neighbors
                
                    **type**: list of    :py:class:`Neighbor<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors.Neighbor>`
                
                    **config**: False
                
                """
                _prefix = 'oc-lldp'
                _revision = '2016-05-16'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "neighbors"
                    self.yang_parent_name = "interface"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Lldp.Interfaces.Interface.Neighbors.Neighbor))])
                    self._leafs = OrderedDict()

                    self.neighbor = YList(self)
                    self._segment_path = lambda: "neighbors"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Lldp.Interfaces.Interface.Neighbors, [], name, value)

                class Neighbor(_Entity_):
                    """
                    List of LLDP neighbors
                    
                    .. attribute:: id  (key)
                    
                         
                    
                        **type**: str
                    
                        **refers to**:  :py:class:`id<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors.Neighbor.State>`
                    
                        **config**: False
                    
                    .. attribute:: config
                    
                        Configuration data 
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors.Neighbor.Config>`
                    
                        **config**: False
                    
                    .. attribute:: state
                    
                        Operational state data 
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors.Neighbor.State>`
                    
                        **config**: False
                    
                    .. attribute:: custom_tlvs
                    
                        Enclosing container for list of custom TLVs from a neighbor
                    
                        **type**:  :py:class:`CustomTlvs<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs>`
                    
                        **config**: False
                    
                    .. attribute:: capabilities
                    
                        Enclosing container for list of LLDP capabilities
                    
                        **type**:  :py:class:`Capabilities<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors.Neighbor.Capabilities>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-lldp'
                    _revision = '2016-05-16'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "neighbors"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("config", ("config", Lldp.Interfaces.Interface.Neighbors.Neighbor.Config)), ("state", ("state", Lldp.Interfaces.Interface.Neighbors.Neighbor.State)), ("custom-tlvs", ("custom_tlvs", Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs)), ("capabilities", ("capabilities", Lldp.Interfaces.Interface.Neighbors.Neighbor.Capabilities))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                        ])
                        self.id = None

                        self.config = Lldp.Interfaces.Interface.Neighbors.Neighbor.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = Lldp.Interfaces.Interface.Neighbors.Neighbor.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"

                        self.custom_tlvs = Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs()
                        self.custom_tlvs.parent = self
                        self._children_name_map["custom_tlvs"] = "custom-tlvs"

                        self.capabilities = Lldp.Interfaces.Interface.Neighbors.Neighbor.Capabilities()
                        self.capabilities.parent = self
                        self._children_name_map["capabilities"] = "capabilities"
                        self._segment_path = lambda: "neighbor" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Lldp.Interfaces.Interface.Neighbors.Neighbor, ['id'], name, value)

                    class Config(_Entity_):
                        """
                        Configuration data 
                        
                        """
                        _prefix = 'oc-lldp'
                        _revision = '2016-05-16'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "config"
                            self._is_frozen = True


                    class State(_Entity_):
                        """
                        Operational state data 
                        
                        .. attribute:: system_name
                        
                            The system name field shall contain an alpha\-numeric string that indicates the system's administratively assigned name. The system name should be the system's fully qualified domain name. If implementations support IETF RFC 3418, the sysName object should be used for this field
                        
                            **type**: str
                        
                                **length:** 0..255
                        
                            **config**: False
                        
                        .. attribute:: system_description
                        
                            The system description field shall contain an alpha\-numeric string that is the textual description of the network entity. The system description should include the full name and version identification of the system's hardware type, software operating system, and networking software. If implementations support IETF RFC 3418, the sysDescr object should be used for this field
                        
                            **type**: str
                        
                                **length:** 0..255
                        
                            **config**: False
                        
                        .. attribute:: chassis_id
                        
                            The Chassis ID is a mandatory TLV which identifies the chassis component of the endpoint identifier associated with the transmitting LLDP agent
                        
                            **type**: str
                        
                            **config**: False
                        
                        .. attribute:: chassis_id_type
                        
                            This field identifies the format and source of the chassis identifier string. It is an enumerator defined by the LldpChassisIdSubtype object from IEEE 802.1AB MIB
                        
                            **type**:  :py:class:`ChassisIdType<ydk.models.openconfig.openconfig_lldp_types.ChassisIdType>`
                        
                            **config**: False
                        
                        .. attribute:: id
                        
                            System generated identifier for the neighbor on the interface
                        
                            **type**: str
                        
                            **config**: False
                        
                        .. attribute:: age
                        
                            Age since discovery
                        
                            **type**: int
                        
                                **range:** 0..18446744073709551615
                        
                            **config**: False
                        
                            **units**: seconds
                        
                        .. attribute:: last_update
                        
                            Seconds since last update received
                        
                            **type**: int
                        
                                **range:** \-9223372036854775808..9223372036854775807
                        
                            **config**: False
                        
                        .. attribute:: port_id
                        
                            The Port ID is a mandatory TLV which identifies the port component of the endpoint identifier associated with the transmitting LLDP agent. If the specified port is an IEEE 802.3 Repeater port, then this TLV is optional
                        
                            **type**: str
                        
                            **config**: False
                        
                        .. attribute:: port_id_type
                        
                            This field identifies the format and source of the port identifier string. It is an enumerator defined by the PtopoPortIdType object from RFC2922
                        
                            **type**:  :py:class:`PortIdType<ydk.models.openconfig.openconfig_lldp_types.PortIdType>`
                        
                            **config**: False
                        
                        .. attribute:: port_description
                        
                            The binary string containing the actual port identifier for the port which this LLDP PDU was transmitted. The source and format of this field is defined by PtopoPortId from RFC2922
                        
                            **type**: str
                        
                            **config**: False
                        
                        .. attribute:: management_address
                        
                            The Management Address is a mandatory TLV which identifies a network address associated with the local LLDP agent, which can be used to reach the agent on the port identified in the Port ID TLV
                        
                            **type**: str
                        
                            **config**: False
                        
                        .. attribute:: management_address_type
                        
                            The enumerated value for the network address type identified in this TLV. This enumeration is defined in the 'Assigned Numbers' RFC [RFC3232] and the ianaAddressFamilyNumbers object
                        
                            **type**: str
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-lldp'
                        _revision = '2016-05-16'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('system_name', (YLeaf(YType.str, 'system-name'), ['str'])),
                                ('system_description', (YLeaf(YType.str, 'system-description'), ['str'])),
                                ('chassis_id', (YLeaf(YType.str, 'chassis-id'), ['str'])),
                                ('chassis_id_type', (YLeaf(YType.enumeration, 'chassis-id-type'), [('ydk.models.openconfig.openconfig_lldp_types', 'ChassisIdType', '')])),
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('age', (YLeaf(YType.uint64, 'age'), ['int'])),
                                ('last_update', (YLeaf(YType.int64, 'last-update'), ['int'])),
                                ('port_id', (YLeaf(YType.str, 'port-id'), ['str'])),
                                ('port_id_type', (YLeaf(YType.enumeration, 'port-id-type'), [('ydk.models.openconfig.openconfig_lldp_types', 'PortIdType', '')])),
                                ('port_description', (YLeaf(YType.str, 'port-description'), ['str'])),
                                ('management_address', (YLeaf(YType.str, 'management-address'), ['str'])),
                                ('management_address_type', (YLeaf(YType.str, 'management-address-type'), ['str'])),
                            ])
                            self.system_name = None
                            self.system_description = None
                            self.chassis_id = None
                            self.chassis_id_type = None
                            self.id = None
                            self.age = None
                            self.last_update = None
                            self.port_id = None
                            self.port_id_type = None
                            self.port_description = None
                            self.management_address = None
                            self.management_address_type = None
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Lldp.Interfaces.Interface.Neighbors.Neighbor.State, ['system_name', 'system_description', 'chassis_id', 'chassis_id_type', 'id', 'age', 'last_update', 'port_id', 'port_id_type', 'port_description', 'management_address', 'management_address_type'], name, value)


                    class CustomTlvs(_Entity_):
                        """
                        Enclosing container for list of custom TLVs from a
                        neighbor
                        
                        .. attribute:: tlv
                        
                            List of custom LLDP TLVs from a neighbor
                        
                            **type**: list of    :py:class:`Tlv<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs.Tlv>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-lldp'
                        _revision = '2016-05-16'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "custom-tlvs"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("tlv", ("tlv", Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs.Tlv))])
                            self._leafs = OrderedDict()

                            self.tlv = YList(self)
                            self._segment_path = lambda: "custom-tlvs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs, [], name, value)

                        class Tlv(_Entity_):
                            """
                            List of custom LLDP TLVs from a neighbor
                            
                            .. attribute:: type  (key)
                            
                                Reference to type list key
                            
                                **type**: int
                            
                                    **range:** \-2147483648..2147483647
                            
                                **refers to**:  :py:class:`type<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs.Tlv.State>`
                            
                                **config**: False
                            
                            .. attribute:: oui  (key)
                            
                                Reference to oui list key
                            
                                **type**: str
                            
                                **refers to**:  :py:class:`oui<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs.Tlv.State>`
                            
                                **config**: False
                            
                            .. attribute:: oui_subtype  (key)
                            
                                Reference to oui\-subtype list key
                            
                                **type**: str
                            
                                **refers to**:  :py:class:`oui_subtype<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs.Tlv.State>`
                            
                                **config**: False
                            
                            .. attribute:: config
                            
                                Configuration data 
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs.Tlv.Config>`
                            
                                **config**: False
                            
                            .. attribute:: state
                            
                                Operational state data 
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs.Tlv.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-lldp'
                            _revision = '2016-05-16'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "tlv"
                                self.yang_parent_name = "custom-tlvs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['type','oui','oui_subtype']
                                self._child_classes = OrderedDict([("config", ("config", Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs.Tlv.Config)), ("state", ("state", Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs.Tlv.State))])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.str, 'type'), ['int'])),
                                    ('oui', (YLeaf(YType.str, 'oui'), ['str'])),
                                    ('oui_subtype', (YLeaf(YType.str, 'oui-subtype'), ['str'])),
                                ])
                                self.type = None
                                self.oui = None
                                self.oui_subtype = None

                                self.config = Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs.Tlv.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs.Tlv.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "tlv" + "[type='" + str(self.type) + "']" + "[oui='" + str(self.oui) + "']" + "[oui-subtype='" + str(self.oui_subtype) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs.Tlv, ['type', 'oui', 'oui_subtype'], name, value)

                            class Config(_Entity_):
                                """
                                Configuration data 
                                
                                """
                                _prefix = 'oc-lldp'
                                _revision = '2016-05-16'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "tlv"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True


                            class State(_Entity_):
                                """
                                Operational state data 
                                
                                .. attribute:: type
                                
                                    The integer value identifying the type of information contained in the value field
                                
                                    **type**: int
                                
                                        **range:** \-2147483648..2147483647
                                
                                    **config**: False
                                
                                .. attribute:: oui
                                
                                    The organizationally unique identifier field shall contain the organization's OUI as defined in Clause 9 of IEEE Std 802. The high\-order octet is 0 and the low\-order 3 octets are the SMI Network Management Private Enterprise Code of the Vendor in network byte order, as defined in the 'Assigned Numbers' RFC [RFC3232]
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                .. attribute:: oui_subtype
                                
                                    The organizationally defined subtype field shall contain a unique subtype value assigned by the defining organization
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                .. attribute:: value
                                
                                    A variable\-length octet\-string containing the instance\-specific information for this TLV
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-lldp'
                                _revision = '2016-05-16'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "tlv"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', (YLeaf(YType.int32, 'type'), ['int'])),
                                        ('oui', (YLeaf(YType.str, 'oui'), ['str'])),
                                        ('oui_subtype', (YLeaf(YType.str, 'oui-subtype'), ['str'])),
                                        ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                    ])
                                    self.type = None
                                    self.oui = None
                                    self.oui_subtype = None
                                    self.value = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Lldp.Interfaces.Interface.Neighbors.Neighbor.CustomTlvs.Tlv.State, ['type', 'oui', 'oui_subtype', 'value'], name, value)




                    class Capabilities(_Entity_):
                        """
                        Enclosing container for list of LLDP capabilities
                        
                        .. attribute:: capability
                        
                            List of LLDP system capabilities advertised by the neighbor
                        
                            **type**: list of    :py:class:`Capability<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors.Neighbor.Capabilities.Capability>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-lldp'
                        _revision = '2016-05-16'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "capabilities"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("capability", ("capability", Lldp.Interfaces.Interface.Neighbors.Neighbor.Capabilities.Capability))])
                            self._leafs = OrderedDict()

                            self.capability = YList(self)
                            self._segment_path = lambda: "capabilities"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Lldp.Interfaces.Interface.Neighbors.Neighbor.Capabilities, [], name, value)

                        class Capability(_Entity_):
                            """
                            List of LLDP system capabilities advertised by the
                            neighbor
                            
                            .. attribute:: name  (key)
                            
                                Reference to capabilities list key
                            
                                **type**:  :py:class:`LLDPSYSTEMCAPABILITY<ydk.models.openconfig.openconfig_lldp_types.LLDPSYSTEMCAPABILITY>`
                            
                                **config**: False
                            
                            .. attribute:: config
                            
                                Configuration data for LLDP capabilities
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors.Neighbor.Capabilities.Capability.Config>`
                            
                                **config**: False
                            
                            .. attribute:: state
                            
                                Operational state data for LLDP capabilities
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_lldp.Lldp.Interfaces.Interface.Neighbors.Neighbor.Capabilities.Capability.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-lldp'
                            _revision = '2016-05-16'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "capabilities"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("config", ("config", Lldp.Interfaces.Interface.Neighbors.Neighbor.Capabilities.Capability.Config)), ("state", ("state", Lldp.Interfaces.Interface.Neighbors.Neighbor.Capabilities.Capability.State))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.identityref, 'name'), [('ydk.models.openconfig.openconfig_lldp_types', 'LLDPSYSTEMCAPABILITY')])),
                                ])
                                self.name = None

                                self.config = Lldp.Interfaces.Interface.Neighbors.Neighbor.Capabilities.Capability.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = Lldp.Interfaces.Interface.Neighbors.Neighbor.Capabilities.Capability.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "capability" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Lldp.Interfaces.Interface.Neighbors.Neighbor.Capabilities.Capability, ['name'], name, value)

                            class Config(_Entity_):
                                """
                                Configuration data for LLDP capabilities
                                
                                """
                                _prefix = 'oc-lldp'
                                _revision = '2016-05-16'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True


                            class State(_Entity_):
                                """
                                Operational state data for LLDP capabilities
                                
                                .. attribute:: name
                                
                                    Name of the system capability advertised by the neighbor. Capabilities are represented in a bitmap that defines the primary functions of the system. The capabilities are defined in IEEE 802.1AB
                                
                                    **type**:  :py:class:`LLDPSYSTEMCAPABILITY<ydk.models.openconfig.openconfig_lldp_types.LLDPSYSTEMCAPABILITY>`
                                
                                    **config**: False
                                
                                .. attribute:: enabled
                                
                                    Indicates whether the corresponding system capability is enabled on the neighbor
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-lldp'
                                _revision = '2016-05-16'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.identityref, 'name'), [('ydk.models.openconfig.openconfig_lldp_types', 'LLDPSYSTEMCAPABILITY')])),
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                    ])
                                    self.name = None
                                    self.enabled = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Lldp.Interfaces.Interface.Neighbors.Neighbor.Capabilities.Capability.State, ['name', 'enabled'], name, value)








    def clone_ptr(self):
        self._top_entity = Lldp()
        return self._top_entity



